@@ -6,7 +6,7 @@ use warnings;
 
 use Games::Dice 'roll';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -15,7 +15,7 @@ sub init {
     $bot->hook(
         {
             command => 'PRIVMSG',
-            text    => qr/roll\s+(?<expr>\d*d[\d%]+(?:[+\-*\/]\d+)?)/,
+            text    => qr/^roll\s+(?<expr>\d*d[\d%]+(?:[+\-*\/]\d+)?)/,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -40,21 +40,13 @@ Bot::IRC::X::Dice - Bot::IRC plugin for dice rolling
 
 =head1 VERSION
 
-version 1.01
+version 1.02
+
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Dice.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Dice)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-Dice/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Dice)
 
 =head1 SYNOPSIS
 
-=head1 DESCRIPTION
-
-This L<Bot::IRC> plugin provides the means for the bot to perform simulated
-dice rolls.
-
-=head2 SEE ALSO
-
-L<Bot::IRC>
-
-=for test_synopsis BEGIN { die "SKIP: Bot::IRC may or may not be available." }
-
     use Bot::IRC;
 
     Bot::IRC->new(
@@ -62,6 +54,55 @@ L<Bot::IRC>
         plugins => ['Dice'],
     )->run;
 
+=head1 DESCRIPTION
+
+This L<Bot::IRC> plugin provides the means for the bot to perform simulated
+dice rolls.
+
+=head1 SEE ALSO
+
+You can look for additional information at:
+
+=over 4
+
+=item *
+
+L<Bot::IRC>
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/Bot-IRC-X-Dice>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/Bot-IRC-X-Dice>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/Bot::IRC::X::Dice>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/Bot-IRC-X-Dice>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/Bot-IRC-X-Dice>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Dice>
+
+=item *
+
+L<CPANTS|http://cpants.cpanauthors.org/dist/Bot-IRC-X-Dice>
+
+=item *
+
+L<CPAN Testers|http://www.cpantesters.org/distro/T/Bot-IRC-X-Dice.html>
+
+=back
+
 =for Pod::Coverage init
 
 =head1 AUTHOR
